{% extends "django_cradmin/base.django.html" %}
{% load i18n %}
{% load static %}

{% block content %}
    <div class="django-cradmin-page-header-outer">
        <div class="container">
            <div class="django-cradmin-page-header-inner">
                <h1>
                    {% trans "Error" %}:
                </h1>
            </div>
        </div>
    </div>
    <div class="container">
        <div class="alert alert-danger">
            {{ error }}
        </div>
    </div>
{% endblock content %}
