{% extends "django_cradmin/viewhelpers/formview_base.django.html" %}
{% load i18n %}
{% load static %}
{% load crispy_forms_tags %}

{% block title %}
    {% trans "Bulk upload archive images" %}
{% endblock title %}

{% block pageheader-inner %}
    <h1>
        {% trans "Bulk upload archive images" %}
    </h1>
{% endblock pageheader-inner %}
