{% extends "django_cradmin/layouts/standalone/focused-internal.django.html" %}
{% comment %}
    You can replace this template in your own project, and
    override stuff from focused-internal.django.html. This means
    that you can put ``django_cradmin/layouts/standalone/focused.django.html`` in
    your own project, and override it without having to reimplement
    anything.

    We will NEVER add anything to this template by default.
{% endcomment %}
